@@ -144,7 +144,7 @@ ggplot_add.add_risktable <- function (object, plot, object_name) {
 
 update_add_risktable <- function(p, add_risktable_empty_list) {
   # confirm class and structure of object
-  .is_ggsurvfit(p, fun_name = "add_rikstable()")
+  .is_ggsurvfit(p, fun_name = "add_risktable()")
   p +
     ggplot2::theme(
       plot.margin = ggplot2::unit(c(5.5, 5.5, 0, 5.5), "points"),
