@@ -13,12 +13,13 @@
 #' @return a ggplot2 figure
 #' @export
 #'
-#' @examples
+#' @examplesIf !names(grDevices::dev.cur()) %in% c("pdf", "postscript")
 #' p <-
 #'   survfit2(Surv(time, status) ~ sex, data = df_lung) %>%
 #'   ggsurvfit(linewidth = 1) +
 #'   add_confidence_interval() +
-#'   add_risktable(risktable_group = "risktable_stats")
+#'   add_risktable(risktable_group = "risktable_stats") +
+#'   scale_ggsurvfit()
 #'
 #'  p + add_risktable_strata_symbol()
 #'  p + add_risktable_strata_symbol(symbol = "\U25CF", size = 10)
@@ -89,9 +90,7 @@ update_add_risktable_strata_symbol <- function(p, add_risktable_strata_symbol_em
     ) %||%
     "Overall"
 
-  # i hope this will work 100% of the time!
-  # what modifications could a use make the the figures that could break this connection?
-  colors %>% stats::setNames(color_label)
+  rep_len(colors, length.out = length(color_label)) %>% stats::setNames(color_label)
 }
 
 .construct_color_block <- function(color_block_mapping, symbol, ...) {
